@@ -6,7 +6,7 @@ describe 'alarmdefs class' do
     it 'we expect a failure for now' do
       tmpdir = default.tmpdir('alarmdefs')
       pp = <<-EOS
-        class { '::monasca::alarmdefs':
+        class { 'monasca::alarmdefs':
           admin_password => 'foo',
           api_server_url => 'http://127.0.0.1:8070',
           auth_url       => 'http://127.0.0.1:5000',
